@@ -892,7 +892,7 @@ _XtResourceConfigurationEH (
 	int		actual_format;
 	unsigned long	nitems;
 	unsigned long	leftover;
-	unsigned char	*data = NULL;
+	char		*data = NULL;
 	unsigned long	resource_len;
 	char		*data_ptr;
 	char		*resource;
@@ -952,7 +952,7 @@ _XtResourceConfigurationEH (
 		pd->rcm_data, 0L, 8192L,
 		TRUE, XA_STRING,
 		&actual_type, &actual_format, &nitems, &leftover,
-		&data ) == Success && actual_type == XA_STRING
+		(unsigned char **)&data ) == Success && actual_type == XA_STRING
 			   && actual_format == 8) {
 	/*
 	 *      data format is:
@@ -981,7 +981,7 @@ _XtResourceConfigurationEH (
 				resource = XtNewString (data_ptr);
 				value = XtNewString (data_value);
 #ifdef DEBUG
-				fprintf (stderr, "resource_len=%d\n"
+				fprintf (stderr, "resource_len=%d\n",
 					 resource_len);
 				fprintf (stderr, "resource = %s\t value = %s\n",
 					 resource, value);
